@@ -33,26 +33,24 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
-import aws_cdk.aws_iam as _aws_cdk_aws_iam_940a1ce0
-import aws_cdk.core as _aws_cdk_core_f4b25747
+import aws_cdk.aws_iam
+import constructs
 
 
 class ManagedInstanceRole(
-    _aws_cdk_core_f4b25747.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@renovosolutions/cdk-library-managed-instance-role.ManagedInstanceRole",
 ):
     def __init__(
         self,
-        scope: _aws_cdk_core_f4b25747.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         domain_join_enabled: typing.Optional[builtins.bool] = None,
-        managed_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_940a1ce0.ManagedPolicy]] = None,
+        managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.ManagedPolicy]] = None,
         ssm_management_enabled: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
@@ -62,10 +60,6 @@ class ManagedInstanceRole(
         :param managed_policies: The managed policies to apply to the role in addition to the default policies.
         :param ssm_management_enabled: Should the role include SSM management. By default if domainJoinEnabled is true then this role is always included.
         '''
-        if __debug__:
-            type_hints = typing.get_type_hints(_typecheckingstub__83f560e4dc759ebe2ceca3b46424c095a7f4f3617f778ecd424d8a1078704302)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ManagedInstanceRoleProps(
             domain_join_enabled=domain_join_enabled,
             managed_policies=managed_policies,
@@ -74,10 +68,10 @@ class ManagedInstanceRole(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="instanceProfile")
-    def instance_profile(self) -> _aws_cdk_aws_iam_940a1ce0.CfnInstanceProfile:
-        return typing.cast(_aws_cdk_aws_iam_940a1ce0.CfnInstanceProfile, jsii.get(self, "instanceProfile"))
+    def instance_profile(self) -> aws_cdk.aws_iam.CfnInstanceProfile:
+        return typing.cast(aws_cdk.aws_iam.CfnInstanceProfile, jsii.get(self, "instanceProfile"))
 
 
 @jsii.data_type(
@@ -94,7 +88,7 @@ class ManagedInstanceRoleProps:
         self,
         *,
         domain_join_enabled: typing.Optional[builtins.bool] = None,
-        managed_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_940a1ce0.ManagedPolicy]] = None,
+        managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.ManagedPolicy]] = None,
         ssm_management_enabled: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
@@ -102,12 +96,7 @@ class ManagedInstanceRoleProps:
         :param managed_policies: The managed policies to apply to the role in addition to the default policies.
         :param ssm_management_enabled: Should the role include SSM management. By default if domainJoinEnabled is true then this role is always included.
         '''
-        if __debug__:
-            type_hints = typing.get_type_hints(_typecheckingstub__5dc346b2a1a5c2a6efa7437dd14db41986afb15e073cd0b7f07a5535dff51898)
-            check_type(argname="argument domain_join_enabled", value=domain_join_enabled, expected_type=type_hints["domain_join_enabled"])
-            check_type(argname="argument managed_policies", value=managed_policies, expected_type=type_hints["managed_policies"])
-            check_type(argname="argument ssm_management_enabled", value=ssm_management_enabled, expected_type=type_hints["ssm_management_enabled"])
-        self._values: typing.Dict[builtins.str, typing.Any] = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if domain_join_enabled is not None:
             self._values["domain_join_enabled"] = domain_join_enabled
         if managed_policies is not None:
@@ -124,10 +113,10 @@ class ManagedInstanceRoleProps:
     @builtins.property
     def managed_policies(
         self,
-    ) -> typing.Optional[typing.List[_aws_cdk_aws_iam_940a1ce0.ManagedPolicy]]:
+    ) -> typing.Optional[typing.List[aws_cdk.aws_iam.ManagedPolicy]]:
         '''The managed policies to apply to the role in addition to the default policies.'''
         result = self._values.get("managed_policies")
-        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_iam_940a1ce0.ManagedPolicy]], result)
+        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_iam.ManagedPolicy]], result)
 
     @builtins.property
     def ssm_management_enabled(self) -> typing.Optional[builtins.bool]:
@@ -156,23 +145,3 @@ __all__ = [
 ]
 
 publication.publish()
-
-def _typecheckingstub__83f560e4dc759ebe2ceca3b46424c095a7f4f3617f778ecd424d8a1078704302(
-    scope: _aws_cdk_core_f4b25747.Construct,
-    id: builtins.str,
-    *,
-    domain_join_enabled: typing.Optional[builtins.bool] = None,
-    managed_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_940a1ce0.ManagedPolicy]] = None,
-    ssm_management_enabled: typing.Optional[builtins.bool] = None,
-) -> None:
-    """Type checking stubs"""
-    pass
-
-def _typecheckingstub__5dc346b2a1a5c2a6efa7437dd14db41986afb15e073cd0b7f07a5535dff51898(
-    *,
-    domain_join_enabled: typing.Optional[builtins.bool] = None,
-    managed_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_940a1ce0.ManagedPolicy]] = None,
-    ssm_management_enabled: typing.Optional[builtins.bool] = None,
-) -> None:
-    """Type checking stubs"""
-    pass
